@@ -5,10 +5,15 @@
 
 package Alien::libtermkey;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
+
+# libdir is the first @INC path that contains a pkgconfig/ dir
+my $libdir;
+foreach my $inc ( @INC ) {
+   $libdir = $inc and last if -d "$inc/pkgconfig";
+}
+defined $libdir or die "Cannot find my libdir containing pkgconfig";
 
-use ExtUtils::PkgConfig;
-my $libdir = '@LIBDIR@';
 my $module = '@PKGCONFIG_MODULE@';
 
 =head1 NAME
@@ -51,7 +56,12 @@ sub _get_pkgconfig
    my ( $method, $self, @args ) = @_;
 
    local $ENV{PKG_CONFIG_PATH} = "$libdir/pkgconfig/";
-   return ExtUtils::PkgConfig->$method( $module, @args );
+   open my $eupc, "-|", "pkg-config", "--define-variable=libdir=$libdir", "--$method", @args, $module or
+      die "Cannot popen pkg-config - $!";
+
+   my $ret = do { local $/; <$eupc> }; chomp $ret;
+
+   return $ret;
 }
 
 sub libs
